pecos.error\_models.fake\_error\_model
======================================

.. automodule:: pecos.error_models.fake_error_model











   .. rubric:: Classes

   .. autosummary::

      FakeErrorModel
